#!/bin/bash
#

#
# sphinx is a product that is always built unqualified
#
# build_sphinx.sh  <product_directory> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <p372> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir()
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`

    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

if [[ -z "${basequal}" ]] || [[ "${basequal}" == "tar" ]]
then
  echo "Python qualifier is mandatory." 1>&2
  usage
  exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=sphinx
origpkgver=v2_0_1
pkgver=${origpkgver}
ssibuildshims_version=v1_04_13
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g'`
pkgtarname=${package}-${pkgdotver}
get_this_dir
get_ssibuildshims

source define_basics NO_TYPE NO_DEBUG_SOURCE

if [ "${maketar}" = "tar" ] && [ -d "${pkgdir}/bin" ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${product_dir}" "${package}" "${pkgver}" "${basequal}"
   exit 0
fi

echo "building ${package} for ${OS}-${plat}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${basequal} || \
  ssi_die "fake declare failed"

# setup
setup -B ${package} ${pkgver} -q ${basequal} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "fake setup failed"

# work in a build directory, which will not be part of any distribution
cd ${blddir} || ssi_die "Unable to cd into ${blddir}"
tar xf ${tardir}/${pkgtarname}.tar || ssi_die "Failed to untar ${pkgtarname}.tar"
cd ${package}-${pkgdotver} || ssi_die "Failed to cd into ${package}-${pkgdotver}"

# Python short version for use in paths.
python_shortdotversion=${PYTHON_VERSION#v}
python_shortdotversion=${python_shortdotversion//_/.}
python_shortdotversion=${python_shortdotversion%.*}

site_packages_dir="${pkgdir}/lib/python${python_shortdotversion}/site-packages/"
mkdir -p ${site_packages_dir} || ssi_die "Failed to create the site_packages directory ${site_packages_dir}"

# These are sanity checks
echo
echo $PYTHONPATH
which python
echo

python setup.py install --prefix ${pkgdir} || ssi_die "python setup.py install failed"

if [ ! -d ${pkgdir}/lib ] || [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/lib or ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

#replace hardwired python path
binlist=`ls ${pkgdir}/bin`
for f in ${binlist}; do
  echo "fixing ${f}"
  fullname=${pkgdir}/bin/${f}
  sed '1s/^.*$/#!\/usr\/bin\/env python /' ${fullname} > ${fullname}tmp
  mv ${fullname}tmp ${fullname}
  chmod 755 ${fullname}
done

# More sanity checks
cd ${blddir} && sphinx-quickstart --project TEST --sep --author $(whoami) --release x.y.z --language en . || ssi_die "Simple quick-start failed."

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${basequal} || ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} -q ${basequal} -z ${product_dir}
echo "sphinx is installed at ${SPHINX_FQ_DIR}"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d "${pkgdir}/bin" ]
then
  ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${product_dir}" "${package}" "${pkgver}" "${basequal}"
fi

exit 0
